@@ -436,7 +436,7 @@ function(input, output, session) {
   regularmodelstring = reactive({
     tryCatch({
       if(any(unlist(strsplit(as.character(as.formula(input$model)[2]),"\\s\\+\\s|\\s\\*\\s|\\:")) == ".")) {
-        dotreplace = paste0("(",paste0(names(inputlist()), collapse=" + "),")")
+        dotreplace = paste0("(",paste0(names(candidatesetall()), collapse=" + "),")")
         additionterms = unlist(strsplit(as.character(as.formula(input$model)[2]),"\\s\\+\\s"))
         multiplyterms = unlist(lapply(lapply(strsplit(additionterms,split="\\s\\*\\s"),gsub,pattern="^\\.$",replacement=dotreplace),paste0,collapse=" * "))
         interactionterms = unlist(lapply(lapply(strsplit(multiplyterms,split="\\:"),gsub,pattern="^\\.$",replacement=dotreplace),paste0,collapse=":"))
@@ -731,7 +731,7 @@ function(input, output, session) {
       as.formula(paste0("~",paste(names(inputlist_htctext()),collapse=" + ")))
     } else {
       names = names(inputlist())
-      modelsplit = attr(terms.formula(as.formula(input$model)), "term.labels")
+      modelsplit = attr(terms.formula(as.formula(input$model),data = candidatesetall()), "term.labels")
       regularmodel = rep(FALSE, length(modelsplit))
       for(term in names) {
         regex = paste0("(\\b",term,"\\b)|(\\b",term,":)|(:",term,"\\b)|(\\b",term,"\\s\\*)|(\\*\\s",term,"\\b)|(:",term,":)")
@@ -786,16 +786,15 @@ function(input, output, session) {
 
   runmatrix = reactive({
     input$submitbutton
+    shinyjs::disable("submitbutton")
+    shinyjs::disable("evalbutton")
     if(isolate(input$setseed)) {
       set.seed(isolate(input$seed))
     }
     if(isolate(input$parallel)) {
       showNotification("Searching (no progress bar with multicore on):",type="message")
     }
-    if(isblocking() && isolate(input$optimality) %in% c("Alias","T","G")) {
-      print("Hard-to-change factors are not currently supported for Alias, T, and G optimal designs.")
-    } else {
-
+    tryCatch({
       if(!isblocking()) {
         if(isolate(as.logical(input$parallel))) {
           gen_design(candidateset = isolate(expand.grid(candidatesetall())),
@@ -811,7 +810,7 @@ function(input, output, session) {
             gen_design(candidateset = isolate(expand.grid(candidatesetall())),
                        model = isolate(as.formula(input$model)),
                        trials = isolate(input$trials),
-                       optimality = isolate(optimality()),
+                       optimality = ifelse(toupper(isolate(optimality())) == "ALIAS" && length(isolate(inputlist_htc())) == 1, "D", isolate(optimality())),
                        repeats = isolate(input$repeats),
                        aliaspower = isolate(input$aliaspower),
                        minDopt = isolate(input$mindopt),
@@ -822,7 +821,7 @@ function(input, output, session) {
         spd = gen_design(candidateset = isolate(expand.grid(candidatesetall())),
                          model = isolate(as.formula(blockmodel())),
                          trials = isolate(input$numberblocks),
-                         optimality = isolate(optimality()),
+                         optimality = ifelse(toupper(isolate(optimality())) == "ALIAS" && length(isolate(inputlist_htc())) == 1, "D", isolate(optimality())),
                          repeats = isolate(input$repeats),
                          varianceratio = isolate(input$varianceratio),
                          aliaspower = isolate(input$aliaspower),
@@ -865,7 +864,10 @@ function(input, output, session) {
                        progressBarUpdater = incProgressSession)})
         }
       }
-    }
+    },finally = {
+      shinyjs::enable("evalbutton")
+      shinyjs::enable("submitbutton")
+    })
   })
 
   evaluationtype = reactive({
@@ -875,18 +877,14 @@ function(input, output, session) {
 
   powerresults = reactive({
     input$evalbutton
-    if(isblocking() && isolate(optimality()) %in% c("Alias","T","G")) {
-      print("No design generated")
-    } else {
-      if(evaluationtype() == "lm") {
-        eval_design(RunMatrix = isolate(runmatrix()),
-                    model = as.formula(isolate(input$model)),
-                    alpha = isolate(input$alpha),
-                    blocking = isblocking(),
-                    effectsize = isolate(effectsize()),
-                    conservative = isolate(input$conservative),
-                    detailedoutput = isolate(input$detailedoutput))
-      }
+    if(evaluationtype() == "lm") {
+      eval_design(RunMatrix = isolate(runmatrix()),
+                  model = as.formula(isolate(input$model)),
+                  alpha = isolate(input$alpha),
+                  blocking = isblocking(),
+                  effectsize = isolate(effectsize()),
+                  conservative = isolate(input$conservative),
+                  detailedoutput = isolate(input$detailedoutput))
     }
   })
   powerresultsglm = reactive({
@@ -897,11 +895,21 @@ function(input, output, session) {
     if(isolate(input$parallel_eval_glm)) {
       showNotification("Simulating (no progress bar with multicore on):",type="message")
     }
-    if(isblocking() && isolate(optimality()) %in% c("Alias","T","G")) {
-      print("No design generated")
-    } else {
-      if(evaluationtype() == "glm") {
-        if(isolate(input$parallel_eval_glm)) {
+    if(evaluationtype() == "glm") {
+      if(isolate(input$parallel_eval_glm)) {
+        eval_design_mc(RunMatrix = isolate(runmatrix()),
+                       model = isolate(as.formula(input$model)),
+                       alpha = isolate(input$alpha),
+                       blocking = isblocking(),
+                       nsim = isolate(input$nsim),
+                       varianceratios = isolate(input$varianceratio),
+                       glmfamily = isolate(input$glmfamily),
+                       effectsize = isolate(effectsize()),
+                       parallel = isolate(input$parallel_eval_glm),
+                       detailedoutput = isolate(input$detailedoutput),
+                       advancedoptions = list(GUI=TRUE))
+      } else {
+        withProgress(message = ifelse(isblocking(),"Simulating (with REML):","Simulating:"), value=0, min = 0, max = 1, expr = {
           eval_design_mc(RunMatrix = isolate(runmatrix()),
                          model = isolate(as.formula(input$model)),
                          alpha = isolate(input$alpha),
@@ -911,21 +919,8 @@ function(input, output, session) {
                          glmfamily = isolate(input$glmfamily),
                          effectsize = isolate(effectsize()),
                          parallel = isolate(input$parallel_eval_glm),
-                         detailedoutput = isolate(input$detailedoutput))
-        } else {
-          withProgress(message = ifelse(isblocking(),"Simulating (with REML):","Simulating:"), value=0, min = 0, max = 1, expr = {
-            eval_design_mc(RunMatrix = isolate(runmatrix()),
-                           model = isolate(as.formula(input$model)),
-                           alpha = isolate(input$alpha),
-                           blocking = isblocking(),
-                           nsim = isolate(input$nsim),
-                           varianceratios = isolate(input$varianceratio),
-                           glmfamily = isolate(input$glmfamily),
-                           effectsize = isolate(effectsize()),
-                           parallel = isolate(input$parallel_eval_glm),
-                           detailedoutput = isolate(input$detailedoutput),
-                           progressBarUpdater = incProgressSession)})
-        }
+                         detailedoutput = isolate(input$detailedoutput),
+                         advancedoptions = list(GUI=TRUE, progressBarUpdater = incProgressSession))})
       }
     }
   })
@@ -940,11 +935,20 @@ function(input, output, session) {
     if(isblocking()) {
       print("Hard-to-change factors are not supported for survival designs. Evaluating design with no blocking.")
     }
-    if(isblocking() && isolate(optimality()) %in% c("Alias","T","G")) {
-      print("No design generated")
-    } else {
-      if(evaluationtype() == "surv") {
-        if(isolate(input$parallel_eval_glm)) {
+    if(evaluationtype() == "surv") {
+      if(isolate(input$parallel_eval_glm)) {
+        eval_design_survival_mc(RunMatrix = isolate(runmatrix()),
+                                model = isolate(as.formula(input$model)),
+                                alpha = isolate(input$alpha),
+                                nsim = isolate(input$nsim),
+                                censorpoint = isolate(input$censorpoint),
+                                censortype = isolate(input$censortype),
+                                distribution = isolate(input$distribution),
+                                effectsize = isolate(effectsize()),
+                                detailedoutput = isolate(input$detailedoutput),
+                                parallel = isolate(input$parallel_eval_glm))
+      } else {
+        withProgress(message = "Simulating:", value=0, min = 0, max = 1, expr = {
           eval_design_survival_mc(RunMatrix = isolate(runmatrix()),
                                   model = isolate(as.formula(input$model)),
                                   alpha = isolate(input$alpha),
@@ -954,22 +958,9 @@ function(input, output, session) {
                                   distribution = isolate(input$distribution),
                                   effectsize = isolate(effectsize()),
                                   detailedoutput = isolate(input$detailedoutput),
-                                  parallel = isolate(input$parallel_eval_glm))
-        } else {
-          withProgress(message = "Simulating:", value=0, min = 0, max = 1, expr = {
-            eval_design_survival_mc(RunMatrix = isolate(runmatrix()),
-                                    model = isolate(as.formula(input$model)),
-                                    alpha = isolate(input$alpha),
-                                    nsim = isolate(input$nsim),
-                                    censorpoint = isolate(input$censorpoint),
-                                    censortype = isolate(input$censortype),
-                                    distribution = isolate(input$distribution),
-                                    effectsize = isolate(effectsize()),
-                                    detailedoutput = isolate(input$detailedoutput),
-                                    parallel = isolate(input$parallel_eval_glm),
-                                    progressBarUpdater = incProgressSession)
-          })
-        }
+                                  parallel = isolate(input$parallel_eval_glm),
+                                  progressBarUpdater = incProgressSession)
+        })
       }
     }
   })
@@ -1025,7 +1016,6 @@ function(input, output, session) {
       }
     }
   }
-  #,rownames=TRUE, bordered=TRUE,hover=TRUE,align="c")
 
   output$powerresults = renderTable({
     powerresults()
@@ -1041,23 +1031,15 @@ function(input, output, session) {
 
   output$aliasplot = renderPlot({
     input$submitbutton
-    if(isolate(isblocking()) && isolate(optimality()) %in% c("Alias","T","G")) {
-      print("No design generated")
-    } else {
-      tryCatch({
-        plot_correlations(isolate(runmatrix()))
-      }, error = function(e) {
-      })
-    }
+    tryCatch({
+      plot_correlations(isolate(runmatrix()))
+    }, error = function(e) {
+    })
   })
 
   output$fdsplot = renderPlot({
     input$submitbutton
-    if(isolate(isblocking()) && isolate(optimality()) %in% c("Alias","T","G")) {
-      print("No design generated")
-    } else {
-      plot_fds(isolate(runmatrix()))
-    }
+    plot_fds(isolate(runmatrix()))
   })
 
   output$code = renderUI({
